@@ -19,7 +19,6 @@ use crate::{
     utils::parse_uri,
 };
 
-#[cfg(feature = "lyric-finder")]
 use crate::utils::map_join;
 use anyhow::{Context as _, Result};
 
@@ -547,18 +546,10 @@ fn handle_global_command(
         Command::Shuffle => {
             client_pub.send(ClientRequest::Player(PlayerRequest::Shuffle))?;
         }
-        Command::VolumeUp => {
+        Command::VolumeChange { offset } => {
             if let Some(ref playback) = state.player.read().buffered_playback {
                 if let Some(volume) = playback.volume {
-                    let volume = std::cmp::min(volume + 5, 100_u32);
-                    client_pub.send(ClientRequest::Player(PlayerRequest::Volume(volume as u8)))?;
-                }
-            }
-        }
-        Command::VolumeDown => {
-            if let Some(ref playback) = state.player.read().buffered_playback {
-                if let Some(volume) = playback.volume {
-                    let volume = volume.saturating_sub(5_u32);
+                    let volume = std::cmp::min(volume as i32 + offset, 100_i32);
                     client_pub.send(ClientRequest::Player(PlayerRequest::Volume(volume as u8)))?;
                 }
             }
@@ -742,22 +733,22 @@ fn handle_global_command(
                 tracing::warn!("clipboard's content ({content}) is not a valid Spotify link!");
             }
         }
-        #[cfg(feature = "lyric-finder")]
-        Command::LyricPage => {
+        Command::LyricsPage => {
             if let Some(rspotify::model::PlayableItem::Track(track)) =
                 state.player.read().currently_playing()
             {
-                let artists = map_join(&track.artists, |a| &a.name, ", ");
-                ui.new_page(PageState::Lyric {
-                    track: track.name.clone(),
-                    artists: artists.clone(),
-                    scroll_offset: 0,
-                });
+                if let Some(id) = &track.id {
+                    let artists = map_join(&track.artists, |a| &a.name, ", ");
+                    ui.new_page(PageState::Lyrics {
+                        track_uri: id.uri(),
+                        track: track.name.clone(),
+                        artists,
+                    });
 
-                client_pub.send(ClientRequest::GetLyric {
-                    track: track.name.clone(),
-                    artists,
-                })?;
+                    client_pub.send(ClientRequest::GetLyrics {
+                        track_id: id.clone_static(),
+                    })?;
+                }
             }
         }
         Command::SwitchDevice => {
